
#include <iostream>
#include <iomanip>
#include <complex>
#include <vector>
#include <cmath>

using namespace std;

#define EPS (1E-12)
#define EQ(x,y) (fabs((x)-(y))<EPS)



typedef complex<double> xy;
const double PI = atan(1.0)*4.0;
bool xy_less(const xy &a, const xy &b){
	return a.real() <b.real() ||(a.real()==b.real()&&a.imag()<b.imag());
}

double normalize_arg(double a){
	while(a>=PI) a-= PI;
	while(a<0) a+= PI;
	return a;
}
void update_ans(double &min_arg, double &min_score,
								double &max_arg, double &max_score,
								double &cur_arg, double &cur_score){
	if(min_score > cur_score){
		min_arg   = cur_arg;
		min_score = cur_score;
	}
	if(max_score < cur_score){
		max_arg   = cur_arg;
		max_score = cur_score;
	}
}
double calc_score(vector<xy> &points,double r){
	double ans;
	double base;
	vector<double> ys;
	xy rot = xy(cos(-r), sin(-r));
	for(int i=0;i<points.size();i++)
		ys.push_back((points[i]*rot).imag());
	sort(ys.begin(), ys.end());
	ans = 2.0;
	for(int i=0;i<ys.size()-1;i++)
		ans += min(2.0, ys[i+1]-ys[i]);
	return ans;
}
void calc_connection(vector<xy> &points,double r, vector<pair<int,int> >&out){
	vector<pair<double,int> > y_idxs;
	xy rot = xy(cos(-r), sin(-r));
	int n = points.size();
	for(int i=0;i<n;i++)
		y_idxs.push_back(make_pair((points[i]*rot).imag(), i));
	sort(y_idxs.begin(), y_idxs.end());
	for(int i=0;i<n; i++){
		int end = i;
		while(end != n-1 && y_idxs[end+1].first-y_idxs[end].first<2.0) end++;
		if(end != i)
			out.push_back(make_pair(y_idxs[i].second,y_idxs[end].second));
		i = end;
	}
}



int main(void){
	int n;
	while(true){
		cin >> n;
		if(!n) break;
		vector<xy> points;
		for(int i=0;i<n;i++){
			double x,y;
			cin >> x >> y;
			points.push_back(xy(x,y));
		}
		vector<double> events;
		events.push_back(0.0);
		events.push_back(PI/2.0);
		events.push_back(PI);
		for(int i=0;i<n;i++){
			for(int j=i+1;j<n;j++){
				double dist = abs(points[i]-points[j]);
				double darg = asin(2.0/dist);
				double narg = arg(points[i]-points[j]);
				if(EQ(dist,2.0)) continue;
				events.push_back(normalize_arg(narg));
				events.push_back(normalize_arg(narg+darg));
				events.push_back(normalize_arg(narg-darg));
			}
		}
		sort(events.begin(), events.end());
		double min_arg, max_arg, min_score = 1E10, max_score = -1.0;
		// exactly
		for(int i=0;i<events.size(); i++){
			double e = events[i];
			double score = calc_score(points, e);
			update_ans(min_arg, min_score, max_arg, max_score, e, score);
		}
		// middle event
		for(int i=0;i<events.size()-1; i++){
			double e1 = events[i];
			double e2 = events[i+1];
			double em = (e1+e2)/2.0;
			if(EQ(e1,e2)) continue;
			vector<pair<int,int> > connections;
			calc_connection(points, em, connections);
			double a = 0.0, b = 0.0; // a sin(r)+b cos(r) 
			if(connections.size()==0) continue;
			for(int i=0;i<connections.size();i++){
				int t1 = connections[i].first;
				int t2 = connections[i].second;
				double L = abs(points[t1]-points[t2]);
				double narg = arg(points[t1]-points[t2]);
				// target len = L sin(narg - r) = L sin(r+PI-narg)
				a += L * cos(PI-narg);
				b += L * sin(PI-narg);
			}
			if(a==0.0 && b==0.0) continue; // cause NaN
			double alpha = asin(b/sqrt(a*a+b*b));
			if(a<0.0)
				alpha  = PI - alpha;
			double trg[2];
			trg[0] = normalize_arg(PI/2.0 - alpha);
			trg[1] = normalize_arg(-PI/2.0 - alpha);
			for(int j=0;j<2;j++)
				if(e1 < trg[j] && trg[j] < e2){
					double score = calc_score(points,trg[j]);
					update_ans(min_arg, min_score, max_arg, max_score, trg[j], score);
				}
		}
		min_arg = PI - min_arg;
		max_arg = PI - max_arg;
		cout << fixed << setprecision(10) << min_arg << endl;
		cout << fixed << setprecision(10) << max_arg << endl;
	}
	return 0;
}
